#!/usr/bin/env python
# -*- coding: utf-8 -*-

# geoarray, A fast Python interface for image geodata - either on disk or in memory.
#
# Copyright (C) 2017-2023
# - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
# - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
#   Germany (https://www.gfz-potsdam.de/)
#
# This software was developed within the context of the GeoMultiSens project funded
# by the German Federal Ministry of Education and Research
# (project grant code: 01 IS 14 010 A-C).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
test_masks
----------

Tests for the geoarray.masks module.
"""

from unittest import TestCase
import numpy as np

from geoarray import NoDataMask, BadDataMask


class Test_NoDataMask(TestCase):
    def test_init_from_bool(self):
        NoDataMask(np.array([[True, False], [False, False]]))

    def test_init_from_int(self):
        NoDataMask(np.array([[1, 0], [0, 0]]))

    def test_init_out_of_range(self):
        with self.assertRaises(AssertionError):
            NoDataMask(np.array([[2, 0], [5, 0]]))

        with self.assertRaises(AssertionError):
            NoDataMask(np.array([[5, 2], [2, 5]]))


class Test_BadDataMask(TestCase):
    def test_init_from_bool(self):
        BadDataMask(np.array([[True, False], [False, False]]))

    def test_init_from_int(self):
        BadDataMask(np.array([[1, 0], [0, 0]]))

    def test_init_out_of_range(self):
        with self.assertRaises(AssertionError):
            BadDataMask(np.array([[2, 0], [5, 0]]))

        with self.assertRaises(AssertionError):
            BadDataMask(np.array([[5, 2], [2, 5]]))


if __name__ == '__main__':
    import pytest
    pytest.main()
